@@ -6,13 +6,6 @@ class TestBooleanPreference(BooleanPreference):
     pass
 
 
-class TestOverrideBooleanPreference(BooleanPreference):
-    field_attributes = {
-        "required": True,
-        "initial": True
-    }
-
-
 
 class TestStringPreference(StringPreference):
 
